#!/usr/bin/env eco

local time = require 'eco.time'

-- Set a timer to execute the callback function after 0.5 seconds
time.at(0.5, function(tmr, start)
    print(time.now() - start, 'seconds after')
end, time.now())

local tmr = time.at(function(tmr)
    print('I will be canceled')
end)

-- Start the timer
tmr:set(3.0)

-- Cancel the timer
tmr:cancel()

time.at(1.0, function(tmr)
    print('repeat:', time.now())
    tmr:set(1.0)
end)
